##  Step 1: Install the LeanIX Reporting CLI
To get started, install the LeanIX Reporting CLI using the following command:

```
npm install -g @leanix/reporting-cli
```



To verify the installation, run the following command:

```
lxr --version
```



